import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["variant", "color", "className", "children", "width", "height", "style", "checked", "defaultChecked", "disabled", "id", "indeterminate", "invalid", "required", "value", "name", "onChange", "aria-labelledby", "aria-describedby"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import * as React from 'react';
import cx from 'classnames';
import Checkbox from '../form-elements/checkbox/Checkbox';
import generateRandomString from '../../js/generateRandomString';
export var CardCheckboxContext = /*#__PURE__*/React.createContext({
  checked: false,
  disabled: false,
  indeterminate: false
});
export var CardCheckboxRoot = /*#__PURE__*/React.forwardRef(function (_ref, ref) {
  var _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'outline' : _ref$variant,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'dark' : _ref$color,
      className = _ref.className,
      children = _ref.children,
      width = _ref.width,
      height = _ref.height,
      style = _ref.style,
      checked = _ref.checked,
      _ref$defaultChecked = _ref.defaultChecked,
      defaultChecked = _ref$defaultChecked === void 0 ? false : _ref$defaultChecked,
      disabled = _ref.disabled,
      id = _ref.id,
      indeterminate = _ref.indeterminate,
      _ref$invalid = _ref.invalid,
      invalid = _ref$invalid === void 0 ? false : _ref$invalid,
      _ref$required = _ref.required,
      required = _ref$required === void 0 ? false : _ref$required,
      value = _ref.value,
      name = _ref.name,
      onChange = _ref.onChange,
      ariaLabelledBy = _ref['aria-labelledby'],
      ariaDescribedBy = _ref['aria-describedby'],
      props = _objectWithoutProperties(_ref, _excluded);

  var isControlled = checked !== undefined;

  var _React$useState = React.useState(isControlled ? checked : defaultChecked),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      isChecked = _React$useState2[0],
      setIsChecked = _React$useState2[1];

  var cardId = React.useMemo(function () {
    return id || generateRandomString();
  }, [id]);
  var cssVariables = {
    '--card-width': width,
    '--card-height': height
  };
  var onInputChange = React.useCallback(function (e) {
    if (!isControlled) {
      setIsChecked(function (val) {
        return !val;
      });
    }

    if (onChange) onChange(e);
  }, [onChange, isControlled]);
  React.useEffect(function () {
    if (isControlled) {
      setIsChecked(checked);
    }
  }, [checked, isControlled]);
  return /*#__PURE__*/React.createElement(CardCheckboxContext.Provider, {
    value: {
      checked: isChecked,
      indeterminate: indeterminate,
      disabled: disabled
    }
  }, /*#__PURE__*/React.createElement("label", _extends({
    className: cx('sg-card-interactive', className),
    style: _objectSpread(_objectSpread({}, style), cssVariables),
    "data-variant": variant,
    "data-color": color,
    "data-checked": indeterminate ? 'mixed' : isChecked,
    "data-invalid": invalid,
    "data-disabled": disabled,
    id: "label-".concat(cardId),
    htmlFor: cardId // On iOS the :active pseudo state is triggered only when there is a touch event set on the HTML element
    // and we use active pseudo class to provide press feedback.
    ,
    onTouchStart: function onTouchStart() {
      return null;
    },
    suppressHydrationWarning: true
  }, props), /*#__PURE__*/React.createElement("input", {
    id: cardId,
    ref: ref,
    className: "sg-card-interactive__input",
    type: "checkbox",
    checked: isChecked,
    disabled: disabled,
    name: name,
    onChange: onInputChange,
    required: required,
    value: value,
    "aria-checked": indeterminate ? 'mixed' : isChecked,
    "aria-invalid": invalid ? true : undefined,
    "aria-labelledby": ariaLabelledBy || "label-".concat(cardId),
    "aria-describedby": ariaDescribedBy,
    suppressHydrationWarning: true
  }), /*#__PURE__*/React.createElement("div", {
    className: "sg-card-interactive__border"
  }, /*#__PURE__*/React.createElement("div", {
    className: "sg-card-interactive__background"
  }, children))));
});
export var CardCheckboxIndicator = function CardCheckboxIndicator(_ref2) {
  var _ref2$slot = _ref2.slot,
      slot = _ref2$slot === void 0 ? 'top-left' : _ref2$slot,
      style = _ref2.style,
      className = _ref2.className;

  var _React$useContext = React.useContext(CardCheckboxContext),
      checked = _React$useContext.checked,
      disabled = _React$useContext.disabled,
      indeterminate = _React$useContext.indeterminate;

  return /*#__PURE__*/React.createElement("div", {
    className: cx('sg-card-interactive__indicator', "sg-card-interactive__indicator--".concat(slot), className),
    style: style
  }, /*#__PURE__*/React.createElement(Checkbox, {
    checked: checked,
    disabled: disabled,
    indeterminate: indeterminate
  }));
};
var CardCheckbox = Object.assign(CardCheckboxRoot, {
  Indicator: CardCheckboxIndicator
});
CardCheckbox.displayName = 'CardCheckbox';
CardCheckboxIndicator.displayName = 'CardCheckbox.Indicator';
export default CardCheckbox;