import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["variant", "color", "className", "children", "width", "height", "style", "id", "disabled", "required", "invalid", "value", "onChange", "aria-labelledby", "aria-describedby"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import * as React from 'react';
import cx from 'classnames';
import Radio from '../form-elements/radio/Radio';
import generateRandomString from '../../js/generateRandomString';
import { useCardRadioGroupContext } from './CardRadioGroupContext';
export var CardRadioContext = /*#__PURE__*/React.createContext({
  checked: false,
  disabled: false
});
var CardRadio = /*#__PURE__*/React.forwardRef(function (_ref, ref) {
  var _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'outline' : _ref$variant,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'dark' : _ref$color,
      className = _ref.className,
      children = _ref.children,
      width = _ref.width,
      height = _ref.height,
      style = _ref.style,
      id = _ref.id,
      disabled = _ref.disabled,
      _ref$required = _ref.required,
      required = _ref$required === void 0 ? false : _ref$required,
      _ref$invalid = _ref.invalid,
      invalid = _ref$invalid === void 0 ? false : _ref$invalid,
      value = _ref.value,
      onChange = _ref.onChange,
      ariaLabelledBy = _ref['aria-labelledby'],
      ariaDescribedBy = _ref['aria-describedby'],
      props = _objectWithoutProperties(_ref, _excluded);

  var context = useCardRadioGroupContext();
  var cardId = React.useMemo(function () {
    return id || generateRandomString();
  }, [id]);
  var isChecked = context.value === value;
  var isRequired = context.required || required;
  var isDisabled = context.disabled || disabled;
  var isInvalid = context.invalid || invalid;
  var cssVariables = {
    '--card-width': width,
    '--card-height': height
  };

  var handleInputChange = function handleInputChange(e) {
    if (context.onChange) {
      context.onChange(e.target.value);
    }

    if (onChange) {
      onChange(e);
    }
  };

  return /*#__PURE__*/React.createElement(CardRadioContext.Provider, {
    value: {
      checked: isChecked,
      disabled: disabled
    }
  }, /*#__PURE__*/React.createElement("label", _extends({
    className: cx('sg-card-interactive', className),
    style: _objectSpread(_objectSpread({}, style), cssVariables),
    "data-variant": variant,
    "data-color": color,
    "data-checked": isChecked,
    "data-invalid": invalid,
    "data-disabled": disabled,
    id: "label-".concat(cardId),
    htmlFor: cardId // On iOS the :active pseudo state is triggered only when there is a touch event set on the HTML element
    // and we use active pseudo class to provide press feedback.
    ,
    onTouchStart: function onTouchStart() {
      return null;
    },
    suppressHydrationWarning: true
  }, props), /*#__PURE__*/React.createElement("input", {
    id: cardId,
    ref: ref,
    className: "sg-card-interactive__input",
    type: "Radio",
    checked: isChecked,
    disabled: isDisabled,
    name: context.name,
    onChange: handleInputChange,
    required: isRequired,
    value: value,
    "aria-invalid": isInvalid,
    "aria-labelledby": ariaLabelledBy || "label-".concat(cardId),
    "aria-describedby": ariaDescribedBy,
    suppressHydrationWarning: true
  }), /*#__PURE__*/React.createElement("div", {
    className: "sg-card-interactive__border"
  }, /*#__PURE__*/React.createElement("div", {
    className: "sg-card-interactive__background"
  }, children))));
});
export function CardRadioIndicator(_ref2) {
  var _ref2$slot = _ref2.slot,
      slot = _ref2$slot === void 0 ? 'top-left' : _ref2$slot,
      style = _ref2.style,
      className = _ref2.className;

  var _React$useContext = React.useContext(CardRadioContext),
      checked = _React$useContext.checked,
      disabled = _React$useContext.disabled;

  return /*#__PURE__*/React.createElement("div", {
    className: cx('sg-card-interactive__indicator', "sg-card-interactive__indicator--".concat(slot), className),
    style: style
  }, /*#__PURE__*/React.createElement(Radio, {
    checked: checked,
    disabled: disabled
  }));
}
CardRadioIndicator.displayName = 'CardRadioIndicator';
export { CardRadio };