import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["icon", "children", "className", "size", "color", "variant", "withAnimation", "aria-label"];
import * as React from 'react';
import cx from 'classnames';
import Text from '../text/Text';
import Flex from '../flex/Flex';
import Icon from '../icons/Icon';
export var COUNTER_VARIANT = {
  solid: 'solid',
  light: 'light'
};
var SOLID_COLOR_BACKGROUND_MAP = {
  blue: 'blue-60',
  green: 'green-60',
  indigo: 'indigo-60',
  red: 'red-60',
  yellow: 'yellow-40',
  gray: 'gray-40',
  achromatic: 'black'
};
var SOLID_COLOR_TEXT_MAP = {
  blue: 'text-white',
  green: 'text-white',
  indigo: 'text-white',
  red: 'text-white',
  yellow: 'text-black',
  gray: 'text-black',
  achromatic: 'text-white'
};
var LIGHT_COLOR_BACKGROUND_MAP = {
  blue: 'blue-20',
  green: 'green-20',
  indigo: 'indigo-20',
  red: 'red-20',
  yellow: 'yellow-20',
  gray: 'gray-20',
  achromatic: 'white'
};
export var COUNTER_COLOR = {
  BLUE: 'blue',
  GREEN: 'green',
  INDIGO: 'indigo',
  RED: 'red',
  YELLOW: 'yellow',
  GRAY: 'gray',
  ACHROMATIC: 'achromatic'
};
export var COUNTER_SIZE = {
  XS: 'xs',
  XXS: 'xxs'
};

var Counter = function Counter(_ref) {
  var _cx;

  var icon = _ref.icon,
      children = _ref.children,
      className = _ref.className,
      _ref$size = _ref.size,
      size = _ref$size === void 0 ? 'xs' : _ref$size,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? 'red' : _ref$color,
      _ref$variant = _ref.variant,
      variant = _ref$variant === void 0 ? 'solid' : _ref$variant,
      withAnimation = _ref.withAnimation,
      ariaLabel = _ref['aria-label'],
      props = _objectWithoutProperties(_ref, _excluded);

  var backgroundColor = variant === 'solid' ? SOLID_COLOR_BACKGROUND_MAP[color] : LIGHT_COLOR_BACKGROUND_MAP[color];
  var counterClass = cx('sg-counter', (_cx = {}, _defineProperty(_cx, "sg-counter--".concat(String(size)), size), _defineProperty(_cx, "sg-counter--".concat(String(backgroundColor)), backgroundColor), _defineProperty(_cx, 'sg-counter--with-animation', withAnimation), _defineProperty(_cx, 'sg-counter--with-icon', icon), _cx), className);
  var textColor = variant === 'solid' ? SOLID_COLOR_TEXT_MAP[color] : 'text-black';
  var content;
  content = /*#__PURE__*/React.createElement(Text, {
    size: size !== undefined && size !== null && size === 'xxs' ? 'xsmall' : 'small',
    weight: "bold",
    color: textColor,
    className: size === 'xxs' ? 'sg-counter__text' : 'sg-counter__text-spaced',
    "aria-label": ariaLabel
  }, children);

  if (icon) {
    content = /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Flex, {
      className: cx('sg-counter__icon-container', {
        'sg-counter__icon-container--xxs': size === 'xxs'
      })
    }, /*#__PURE__*/React.createElement(Icon, {
      type: icon,
      size: size === 'xxs' ? 16 : 24,
      color: "icon-black",
      className: "sg-counter__icon",
      "aria-hidden": !!ariaLabel
    })), /*#__PURE__*/React.createElement(Flex, {
      alignItems: "center"
    }, /*#__PURE__*/React.createElement(Text, {
      as: "span",
      weight: "bold",
      size: size !== undefined && size !== null && size === 'xxs' ? 'xsmall' : 'small',
      className: "sg-counter__text",
      "aria-label": ariaLabel
    }, children)));
  }

  return /*#__PURE__*/React.createElement("div", _extends({}, props, {
    className: counterClass
  }), content);
};

export default Counter;