import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import * as React from 'react';
import Button from '../../buttons/Button';
import Transition from '../Transition';
import DummyBox from './common/DummyBox';
import Stage from './common/Stage';
import { useIsomorphicLayoutEffect } from '../../utils/useIsomorphicLayoutEffect';
import { useTransformationState } from './common/useTransformationState';
var appearingEffect = {
  initial: {
    opacity: 0,
    transform: {
      scale: 0.9
    }
  },
  animate: {
    opacity: 1,
    duration: 'moderate1'
  }
};
var removingEffect = {
  animate: {
    opacity: 0,
    duration: 'quick2'
  }
};
var initialItemIds = [0, 1, 2, 3];
/**
 * It is greater than the ID of the last initial item to
 * not animate the already added items at the beginning.
 */

var lastUniqueId = initialItemIds.length;
export var FluidList = function FluidList() {
  var containerRef = React.useRef(null);

  var _React$useState = React.useState(initialItemIds),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      itemIds = _React$useState2[0],
      setItemIds = _React$useState2[1];

  var addItem = function addItem() {
    setItemIds(function (prev) {
      return [++lastUniqueId].concat(_toConsumableArray(prev));
    });
  };

  var removeItem = function removeItem(id) {
    setItemIds(function (prev) {
      return prev.filter(function (n) {
        return n !== id;
      });
    });
  };

  return /*#__PURE__*/React.createElement(Stage, {
    ref: containerRef,
    className: "sg-space-y-xs",
    format: "portrait"
  }, /*#__PURE__*/React.createElement(Button, {
    variant: "outline",
    onClick: addItem,
    fullWidth: true
  }, "add item"), itemIds.map(function (id, index) {
    return /*#__PURE__*/React.createElement(FluidListItem, {
      key: id,
      index: index,
      updateKey: itemIds.length,
      containerRef: containerRef,
      lastCreated: id === lastUniqueId,
      siblingsAmount: itemIds.length - 1,
      onRemove: function onRemove() {
        return removeItem(id);
      }
    });
  }));
};

var FluidListItem = function FluidListItem(_ref) {
  var index = _ref.index,
      updateKey = _ref.updateKey,
      containerRef = _ref.containerRef,
      lastCreated = _ref.lastCreated,
      siblingsAmount = _ref.siblingsAmount,
      onRemove = _ref.onRemove;

  var _React$useState3 = React.useState(false),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      removing = _React$useState4[0],
      setRemoving = _React$useState4[1];

  var _React$useState5 = React.useState(null),
      _React$useState6 = _slicedToArray(_React$useState5, 2),
      movementEffect = _React$useState6[0],
      setMovementEffect = _React$useState6[1];

  var elementRef = React.useRef(null);
  var transformation = useTransformationState({
    elementRef: elementRef,
    containerRef: containerRef,
    updateKey: updateKey
  });

  var getTransitionEffect = function getTransitionEffect() {
    if (removing) {
      return removingEffect;
    }

    if (lastCreated) {
      return appearingEffect;
    }

    return movementEffect;
  };

  var getTransitionDelay = function getTransitionDelay() {
    var appearingDelay = 180;
    var delayOffset = 20;

    if (removing || siblingsAmount === 0) {
      return 0;
    }

    if (lastCreated) {
      return appearingDelay;
    }
    /**
     * To simulate weightlessness we can delay the
     * transition of each item when it moves upward.
     */


    if (transformation.diffTop < 0) {
      return appearingDelay + delayOffset * index;
    }

    return 0;
  };

  useIsomorphicLayoutEffect(function () {
    if (transformation.diffTop !== 0) {
      /**
       * https://css-tricks.com/animating-layouts-with-the-flip-technique/
       */
      setMovementEffect({
        initial: {
          transform: {
            translateY: -transformation.diffTop
          }
        },
        animate: {
          transform: {
            translateY: 0,
            duration: 'moderate1'
          }
        }
      });
    }
  }, [transformation]);
  return /*#__PURE__*/React.createElement("div", {
    ref: elementRef
  }, /*#__PURE__*/React.createElement(Transition, {
    active: true,
    effect: getTransitionEffect(),
    delay: getTransitionDelay(),
    onTransitionEnd: removing ? onRemove : undefined,
    fillMode: "backwards"
  }, /*#__PURE__*/React.createElement(DummyBox, {
    color: "blue",
    size: "listitem",
    onClick: function onClick() {
      return setRemoving(true);
    }
  })));
};

FluidList.parameters = {
  layout: 'centered'
};